#[repr(C)]pub struct Elevation {
pub token_is_elevated: bool32,
}Expand description
[docs.microsoft.com] TOKEN_ELEVATION
Fields
token_is_elevated: bool32Trait Implementations
Sourceimpl AsMut<Elevation> for TOKEN_ELEVATION
impl AsMut<Elevation> for TOKEN_ELEVATION
Sourceimpl AsMut<TOKEN_ELEVATION> for Elevation
impl AsMut<TOKEN_ELEVATION> for Elevation
Sourcefn as_mut(&mut self) -> &mut TOKEN_ELEVATION
fn as_mut(&mut self) -> &mut TOKEN_ELEVATION
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl AsRef<Elevation> for TOKEN_ELEVATION
impl AsRef<Elevation> for TOKEN_ELEVATION
Sourceimpl AsRef<TOKEN_ELEVATION> for Elevation
impl AsRef<TOKEN_ELEVATION> for Elevation
Sourcefn as_ref(&self) -> &TOKEN_ELEVATION
fn as_ref(&self) -> &TOKEN_ELEVATION
Converts this type into a shared reference of the (usually inferred) input type.
impl Copy for Elevation
Sourceimpl From<Elevation> for TOKEN_ELEVATION
impl From<Elevation> for TOKEN_ELEVATION
Sourceimpl From<TOKEN_ELEVATION> for Elevation
impl From<TOKEN_ELEVATION> for Elevation
Sourcefn from(ts: TOKEN_ELEVATION) -> Self
fn from(ts: TOKEN_ELEVATION) -> Self
Converts to this type from the input type.